@@ -36,16 +36,40 @@
 using namespace std;
 using namespace Strigi;
 
-bool
-DirLister::nextEntry(EntryInfo& e) {
-    if (pos < (int)entries.size()) {
-        e = entries[pos++];
-    } else {
-        pos = -1;
+class ArchiveReader::DirLister::Private {
+public:
+    int pos;
+    const vector<EntryInfo> entries;
+    Private(const vector<EntryInfo>& v) :entries(v) {
+        pos = 0;
     }
-    return pos != -1;
+    bool
+    nextEntry(EntryInfo& e) {
+        if (pos >= 0 && pos < (int)entries.size()) {
+            e = entries[pos++];
+        } else {
+            pos = -1;
+        }
+        return pos != -1;
+    }
+};
+
+ArchiveReader::DirLister::DirLister(Private* d) :p(d) {
+    assert(d);
 }
 
+ArchiveReader::DirLister::DirLister(const DirLister& dl)
+    :p(new Private(*dl.p)) {
+}
+
+ArchiveReader::DirLister::~DirLister() {
+    delete p;
+}
+
+bool
+ArchiveReader::DirLister::nextEntry(EntryInfo& e) {
+    return p->nextEntry(e);
+}
 
 /**
  * @brief A cache for entries that have already been found.
@@ -98,12 +122,6 @@ public:
      * Contains all the root entries in the cache.
      */
     std::map<std::string, RootSubEntry> cache;
-    // most vexing - this doesn't seem to be defined anywhere
-    // and yet... it compiles. Why? Perhaps because it isn't
-    // called from anywhere...
-    // You'd have thought you'd get a warning, though.
-    // Go figure.
-    vector<EntryInfo> entries(const std::string& url);
 
     /**
      * @brief Find an entry in the cache by its URL
@@ -191,18 +209,16 @@ ArchiveEntryCache::findEntry(const string& url) const {
     }
     const SubEntry* e = &ei->second;
 
-    SubEntryMap::const_iterator i;
-
     size_t p = ei->first.length();
+    string name;
     do {
         size_t np = url.find('/', p+1);
-        string name;
         if (np == string::npos) {
-            name = url.substr(p+1);
+            name.assign(url.substr(p+1));
         } else {
-            name = url.substr(p+1, np-p-1);
+            name.assign(url.substr(p+1, np-p-1));
         }
-        i = e->entries.find(name);
+        SubEntryMap::const_iterator i = e->entries.find(name);
         if (i == e->entries.end()) {
             e = 0;
         } else {
@@ -266,26 +282,26 @@ ArchiveReader::ArchiveReaderPrivate::StreamPtr::free() {
     if (provider) delete provider;
 }
 void
-addEntry(ArchiveEntryCache::SubEntry& e, ArchiveEntryCache::SubEntry& se) {
+addEntry(ArchiveEntryCache::SubEntry* e, ArchiveEntryCache::SubEntry* se) {
     // split path into components
     vector<string> names;
-    string name = se.entry.filename;
+    string name = se->entry.filename;
     string::size_type p = name.find('/');
     while (p != string::npos) {
         names.push_back(name.substr(0, p));
         name = name.substr(p + 1);
         p = name.find('/');
     }
-    names.push_back(name);
-    se.entry.filename = name;
+    se->entry.filename = name;
 
     // find the right entry
     ArchiveEntryCache::SubEntryMap::iterator ii;
-    ArchiveEntryCache::SubEntry* parent = &e;
+    ArchiveEntryCache::SubEntry* parent = e;
     for (uint i=0; i<names.size(); ++i) {
         ii = parent->entries.find(names[i]);
         if (ii == parent->entries.end()) {
-            ArchiveEntryCache::SubEntry *newse = new ArchiveEntryCache::SubEntry;
+            ArchiveEntryCache::SubEntry *newse
+                = new ArchiveEntryCache::SubEntry();
             newse->entry.filename = names[i];
             newse->entry.type = EntryInfo::Dir;
             newse->entry.size = 0;
@@ -294,7 +310,7 @@ addEntry(ArchiveEntryCache::SubEntry& e, ArchiveEntryCache::SubEntry& se) {
         }
         parent = ii->second;
     }
-    *parent = se;
+    parent->entries[name] = se;
 }
 ArchiveReader::ArchiveReaderPrivate::ArchiveReaderPrivate() {
     typedef std::pair<bool (*)(const char*, int32_t),
@@ -407,6 +423,8 @@ ArchiveReader::ArchiveReaderPrivate::subStreamProvider(
         InputStream* input, list<ArchiveReaderPrivate::StreamPtr>& streams
         ) {
     if (input == 0) return 0;
+    // TODO: the magic bytes can be checked without allocating
+    // the BZ2InputStream or GZipInputstream to make the code faster
     InputStream* s = new BZ2InputStream(input);
     if (s->status() == Ok) {
         streams.push_back(s);
@@ -452,18 +470,17 @@ ArchiveReader::ArchiveReaderPrivate::fillEntry(ArchiveEntryCache::SubEntry& e,
     SubStreamProvider* p = subStreamProvider(s, streams);
     if (!p) return 0;
     do {
-        ArchiveEntryCache::SubEntry se;
-        se.entry = p->entryInfo();
-        int nsubentries = fillEntry(se, p->currentEntry());
-        if (se.entry.size < 0) {
+        ArchiveEntryCache::SubEntry* se = new ArchiveEntryCache::SubEntry();
+        se->entry = p->entryInfo();
+        int nsubentries = fillEntry(*se, p->currentEntry());
+        if (se->entry.size < 0) {
             // read entire stream to determine it's size
             InputStream *es = p->currentEntry();
             const char* c;
             while (es->read(c, 1, 0) > 0) {}
-            se.entry.size = es->size();
-            if (se.entry.size < 0) se.entry.size = 0;
+            se->entry.size = max(es->size(), (int64_t)0);
         }
-        addEntry(e, se);
+        addEntry(&e, se);
         if (nsubentries) {
             nentries += nsubentries;
         }
@@ -503,10 +520,9 @@ ArchiveReader::ArchiveReaderPrivate::localStat(const std::string& url, EntryInfo
                 e.type = (EntryInfo::Type)(EntryInfo::Dir|EntryInfo::File);
                 free(streams);
 
-                ArchiveEntryCache::RootSubEntry rse;
+                ArchiveEntryCache::RootSubEntry& rse = cache.cache[url];
                 rse.indexed = false;
                 rse.entry = e;
-                cache.cache[url] = rse;
             }
             delete s;
             return 0;
@@ -572,7 +588,7 @@ ArchiveReader::isArchive(const std::string& url) {
     }
     return e.type & EntryInfo::File && e.type & EntryInfo::Dir;
 }
-DirLister
+ArchiveReader::DirLister
 ArchiveReader::dirEntries(const std::string& url) {
     std::vector<EntryInfo> v;
 
@@ -595,7 +611,7 @@ ArchiveReader::dirEntries(const std::string& url) {
         // or create a new entry
         InputStream* s = 0;
         vector<size_t> l = p->cullName(url, s);
-        if (!s) return DirLister(v);
+        if (!s) return DirLister(new DirLister::Private(v));
         if (l.size()) {
             name = url.substr(0, l[l.size()-1]-1);
         } else {
@@ -603,12 +619,11 @@ ArchiveReader::dirEntries(const std::string& url) {
         }
         EntryInfo e;
         p->localStat(name, e);
-        ArchiveEntryCache::RootSubEntry se;
+        ArchiveEntryCache::RootSubEntry& se = p->cache.cache[name];
         se.indexed = true;
         se.entry = e;
         p->fillEntry(se, s);
         delete s;
-        p->cache.cache[name] = se;
         subentry = p->cache.findEntry(url);
     }
 
@@ -618,7 +633,7 @@ ArchiveReader::dirEntries(const std::string& url) {
             v.push_back(i->second->entry);
         }
     }
-    DirLister dl(v);
+    DirLister dl(new DirLister::Private(v));
     return dl;
 }
 bool
