@@ -22,12 +22,12 @@
 #include "xapianindexwriter.h"
 #include <assert.h>
 using namespace std;
-using namespace jstreams;
+using namespace Strigi;
 using namespace Xapian;
 
 pthread_mutex_t XapianIndexManager::lock = PTHREAD_MUTEX_INITIALIZER;
 
-jstreams::IndexManager*
+Strigi::IndexManager*
 createXapianIndexManager(const char* path) {
     return new XapianIndexManager(path);
 }
@@ -48,7 +48,7 @@ XapianIndexManager::~XapianIndexManager() {
     closedb();
 }
 IndexReader*
-XapianIndexManager::getIndexReader() {
+XapianIndexManager::indexReader() {
     pthread_t self = pthread_self();
     XapianIndexReader* r = readers[self];
     if (r == 0) {
@@ -58,7 +58,7 @@ XapianIndexManager::getIndexReader() {
     return r;
 }
 IndexWriter*
-XapianIndexManager::getIndexWriter() {
+XapianIndexManager::indexWriter() {
     pthread_t self = pthread_self();
     XapianIndexWriter* w = writers[self];
     if (w == 0) {
